from progress.function.decorators import progress, spinner
from progress.class_method.decorators import progress as class_progress
from .logger import get_logger

__all__ = [
    "progress",
    "spinner",
    "class_progress",
    "get_logger",
]



from distutils.core import setup

setup(
    name='python-progress',
    version='0.1.0',
    packages=['python-progress'],
    license='MIT',
    description="Simple function bar and spinner function wrappers",
    author='Mashin Ivan',
    author_email='mivan19@yandex.ru',
    url='https://github.com/MashinIvan/python-progress',
    download_url='https://github.com/MashinIvan/python-progress/archive/refs/tags/v0.1.0.tar.gz',
    keywords=['function', 'function bar', 'loading', 'spinner'],
    install_requires=[],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
    ],
)
